#
# spec file for package pavucontrol-qt
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pavucontrol-qt
Version:        1.4.0
Release:        1.1
Summary:        Qt port of pavucontrol
License:        GPL-2.0-only
Group:          System/GUI/LXQt
URL:            https://github.com/lxqt/pavucontrol-qt
Source:         https://github.com/lxqt/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        https://github.com/lxqt/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.1.0
BuildRequires:  gcc-c++
BuildRequires:  lxqt-build-tools-devel >= 0.13.0
BuildRequires:  pkgconfig
BuildRequires:  xdg-user-dirs
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.15
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libpulse) >= 5.0
BuildRequires:  pkgconfig(libpulse-mainloop-glib) >= 0.9.16
BuildRequires:  pkgconfig(lxqt)
Recommends:     %{name}-lang

%description
PulseAudio Volume Control (pavucontrol) is a simple volume control tool
("mixer") for the PulseAudio sound server. In contrast to classic mixer
tools this one allows you to control both the volume of hardware devices
and of each playback stream separately.

%lang_package

%prep
%setup -q
sed -i '/Name=/s/$/ Qt/' src/%{name}.desktop.in

%build
%cmake \
      -DPULL_TRANSLATIONS=OFF

%install
%cmake_install

%find_lang %{name} --with-qt

%files
%license LICENSE
%doc AUTHORS CHANGELOG README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop

%files lang -f %{name}.lang
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/translations
%{_datadir}/%{name}/translations/*

%changelog
* Mon Nov  6 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.4.0:
  * Updated translations and bumped the version
* Sat Apr 15 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.3.0:
  * Fixed a case of memory leak and updated translations
* Sat Nov  5 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Update to 1.2.0:
  * Improved `Categories` `GenericName`, and `Comment` in the
    desktop entry.
* Fri Apr 29 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.1.0:
  * Cleaned up the code and updated translations.
* Mon Nov  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.0.0:
  * Bumped minimum required Qt version to 5.15.
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.17.0:
  * The redundant dbus dependency is removed.
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.16.0:
  * Safely iterate over card profile info array.
  * Fall back to default icon when no candidate is found.
  * Elide playback name label if needed
  * Don't force a height on progressbars.
  * Remove warnings about unused function parameters.
  * Wrapped the text of connecting error label.
* Mon Apr 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Changed pavucontrol-qt.keyring to tsujan's key
* Sat Apr 25 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 0.15.0
  * Code cleanup.
* Fri Mar  1 2019 mvetter@suse.com
- Update to 0.14.1:
  * Only translations was changed
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.14.0:
  * Treat the ‘off’ card profile specifically
  * Mainwindow: Don’t use deprecated libpulse members
- Move translation from lxqt-l10n into package
* Tue May 22 2018 mvetter@suse.com
- Update to 0.4.0:
  * Bumped minor version to 4
  * Spanish translation update
  * Qt5.11 beta: xxxwidget: include QAction explicitely
  * CMake: Prevent in-source builds
  * build: Use pkg-config's *_LDFLAGS
  * fix http -> https
  * Fixed mentions of LXDE
  * pavucontrol: Remove unique application constraint
  * Add Simplified Chinese desktop entry
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.3.0:
  * Bump version to 0.3.0
  * correct spelling mistake
  * Added Lithuanian .desktop file
  * liblxqt make no sense here
  * Copied issue template
  * set Qt::AA_UseHighDpiPixmaps to true
  * Added version to cli options
  * Added default CMAKE_BUILD_TYPE and versioning
  * added pl.desktop
  * ui: Use "changes-prevent-symbolic" icon
  * MainWindow: Remove old GTK remnants
  * Add Catalan translation
  * Channel: Add slider snapping to 100%%
  * Channel: Address compiler warnings
  * Channel: Align slider controls correclty
  * Channel: Add ticks to volume slider
  * Channel: Use percentage for volume scale
  * devicewidgte: Re-add device renaming
  * MainWindow: Force using the size from previous run
  * MainWindow: Add quit shortcut
  * Added pavucontrol-qt_da.desktop
* Fri Feb 24 2017 sfalken@opensuse.org
- Update to 0.2.0:
  * Release 0.2.0: Update changelog
  * Use QSettings for storing configuration
  * Create pavucontrol-qt_pt.desktop
  * Use the new lxqt-build-tools package
  * - Add a simple single instance controller to avoid run multiple simultaneous applications
  * Use same approach as avidemux
  * Simply differentiate the namnig to avoid menu duplication
  * CMakeLists: Remove XdgUserDirs requirement
  * mainwindow: Set icon for eventRoleWidget
* Sat Sep 24 2016 mvetter@suse.com
- Creating initial package 0.1.0
